@@ -5,8 +5,9 @@ import requests
 import sys
 import argparse
 
-from mutagen.easyid3 import ID3, EasyID3 
-from mutagen.mp3 import EasyMP3
+from mutagen.mp3 import MP3, EasyMP3
+from mutagen.id3 import APIC
+from mutagen.id3 import ID3 as OldID3
 
 from clint.textui import colored, puts, progress
 
@@ -15,6 +16,7 @@ CLIENT_ID = '22e566527758690e6feb2b5cb300cc43'
 CLIENT_SECRET = '3a7815c3f9a82c3448ee4e7d3aa484a4'
 MAGIC_CLIENT_ID = 'b45b1aa10f1ac2941910a7f0d10f8e28'
 
+
 def main():
     parser = argparse.ArgumentParser(description='SoundScrape. Scrape an artist from SoundCloud.\n')
     parser.add_argument('artist_url', metavar='U', type=str,
@@ -67,18 +69,20 @@ def main():
         tracks = client.get('/users/' + str(artist_id) + '/tracks')
 
     if one_track:
-        num_tracks = 1;
+        num_tracks = 1
     else:
         num_tracks = vargs['num_tracks']
     download_tracks(client, tracks, num_tracks)
 
+
 def download_tracks(client, tracks, num_tracks=sys.maxint):
 
     for i, track in enumerate(tracks):
 
-        # "Track" and "Resource" objects are actually different, 
-        # even though they're the same. 
+        # "Track" and "Resource" objects are actually different,
+        # even though they're the same.
         if isinstance(track, soundcloud.resource.Resource):
+
             try:
                 t_track = {}
                 t_track['downloadable'] = track.downloadable
@@ -87,6 +91,7 @@ def download_tracks(client, tracks, num_tracks=sys.maxint):
                 t_track['user'] = {'username': track.user['username']}
                 t_track['release_year'] = track.release
                 t_track['genre'] = track.genre
+                t_track['artwork_url'] = track.artwork_url
                 if track.downloadable:
                     t_track['stream_url'] = track.download_url
                 else:
@@ -104,7 +109,7 @@ def download_tracks(client, tracks, num_tracks=sys.maxint):
             continue
         try:
             if not track.get('stream_url', False):
-                puts(track['title'].encode('utf-8')  + colored.red(u' is not downloadable') + '.')
+                puts(track['title'].encode('utf-8') + colored.red(u' is not downloadable') + '.')
                 continue
             else:
                 puts(colored.green(u"Downloading") + ": " + track['title'].encode('utf-8'))
@@ -119,27 +124,30 @@ def download_tracks(client, tracks, num_tracks=sys.maxint):
 
                 track_filename = track['user']['username'].replace('/', '-') + ' - ' + track['title'].replace('/', '-') + '.mp3'
                 download_file(location, track_filename)
-                tag_file(track_filename, 
-                        artist=track['user']['username'], 
-                        title=track['title'], 
-                        year=track['release_year'], 
-                        genre=track['genre'])
+                tag_file(track_filename,
+                        artist=track['user']['username'],
+                        title=track['title'],
+                        year=track['release_year'],
+                        genre=track['genre'],
+                        artwork_url=track['artwork_url'])
         except Exception, e:
-            puts(colored.red(u"Problem downloading ") + track['title'].encode('utf-8') )
+            puts(colored.red(u"Problem downloading ") + track['title'].encode('utf-8'))
             print e
 
+
 def download_file(url, path):
     r = requests.get(url, stream=True)
     with open(path, 'wb') as f:
         total_length = int(r.headers.get('content-length'))
-        for chunk in progress.bar(r.iter_content(chunk_size=1024), expected_size=(total_length/1024) + 1): 
-            if chunk: # filter out keep-alive new chunks
+        for chunk in progress.bar(r.iter_content(chunk_size=1024), expected_size=(total_length / 1024) + 1):
+            if chunk:  # filter out keep-alive new chunks
                 f.write(chunk)
                 f.flush()
 
     return path
 
-def tag_file(filename, artist, title, year, genre):
+
+def tag_file(filename, artist, title, year, genre, artwork_url):
     try:
         audio = EasyMP3(filename)
         audio["artist"] = artist
@@ -148,6 +156,27 @@ def tag_file(filename, artist, title, year, genre):
             audio["date"] = str(year)
         audio["genre"] = genre
         audio.save()
+
+        if artwork_url:
+            mime = 'image/jpeg'
+            if 'jpg' in artwork_url:
+                mime = 'image/jpeg'
+            if 'png' in artwork_url:
+                mime - 'image/png'
+
+            image_data = requests.get(artwork_url).content
+
+            audio = MP3(filename, ID3=OldID3)
+            audio.tags.add(
+                APIC(
+                    encoding=3, # 3 is for utf-8
+                    mime=mime,
+                    type=3, # 3 is for the cover image
+                    desc=u'Cover',
+                    data=image_data
+                )
+            )
+        audio.save()
     except Exception, e:
         print e
 
